@@ -1,5 +1,6 @@
 #-*- coding: utf-8 -*-
 
+from __future__ import unicode_literals
 import json
 
 from django.http import Http404, HttpResponse
@@ -7,7 +8,7 @@ from django.shortcuts import get_object_or_404
 
 from infinite_scroll_pagination.paginator import SeekPaginator, EmptyPage
 
-from models import Article
+from .models import Article
 
 
 def pagination_ajax(request, pk=None):
